@@ -5,7 +5,11 @@ generate.pathway = function(el) {
         stop("Second dimension of edgelist should be 2.\n")
     }
     
-    el = as.matrix(el)
+	# remove duplicat connections between two nodes
+	el.vector = apply(el, 1, paste, collapse="--")
+	el.vector = unique(el.vector)
+	
+    el = t(as.matrix(as.data.frame(strsplit(el.vector, "--"))))
     
     g = graph.edgelist(el, directed = TRUE)
     
